==> openshift-model-hive-5.12.1-sources.jar: io/fabric8/openshift/api/model/hive/v1/SyncSetBuilder.java <==
package io.fabric8.openshift.api.model.hive.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class SyncSetBuilder extends io.fabric8.openshift.api.model.hive.v1.SyncSetFluentImpl<io.fabric8.openshift.api.model.hive.v1.SyncSetBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.hive.v1.SyncSet,io.fabric8.openshift.api.model.hive.v1.SyncSetBuilder>{
  public SyncSetBuilder() {
    this(false);
  }
  public SyncSetBuilder(java.lang.Boolean validationEnabled) {
    this(new SyncSet(), validationEnabled);
  }
  public SyncSetBuilder(io.fabric8.openshift.api.model.hive.v1.SyncSetFluent<?> fluent) {
    this(fluent, false);
  }
  public SyncSetBuilder(io.fabric8.openshift.api.model.hive.v1.SyncSetFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new SyncSet(), validationEnabled);
  }
  public SyncSetBuilder(io.fabric8.openshift.api.model.hive.v1.SyncSetFluent<?> fluent,io.fabric8.openshift.api.model.hive.v1.SyncSet instance) {
    this(fluent, instance, false);
  }
  public SyncSetBuilder(io.fabric8.openshift.api.model.hive.v1.SyncSetFluent<?> fluent,io.fabric8.openshift.api.model.hive.v1.SyncSet instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withApiVersion(instance.getApiVersion()); 
    fluent.withKind(instance.getKind()); 
    fluent.withMetadata(instance.getMetadata()); 
    fluent.withSpec(instance.getSpec()); 
    fluent.withStatus(instance.getStatus()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public SyncSetBuilder(io.fabric8.openshift.api.model.hive.v1.SyncSet instance) {
    this(instance,false);
  }
  public SyncSetBuilder(io.fabric8.openshift.api.model.hive.v1.SyncSet instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withApiVersion(instance.getApiVersion()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.withSpec(instance.getSpec()); 
    this.withStatus(instance.getStatus()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.hive.v1.SyncSetFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.hive.v1.SyncSet build() {
    SyncSet buildable = new SyncSet(fluent.getApiVersion(),fluent.getKind(),fluent.getMetadata(),fluent.getSpec(),fluent.getStatus());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    SyncSetBuilder that = (SyncSetBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> openshift-model-hive-6.5.1-sources.jar: io/fabric8/openshift/api/model/hive/v1/SyncSetBuilder.java <==
package io.fabric8.openshift.api.model.hive.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class SyncSetBuilder extends SyncSetFluentImpl<SyncSetBuilder> implements VisitableBuilder<SyncSet,SyncSetBuilder>{
  public SyncSetBuilder() {
    this(false);
  }
  public SyncSetBuilder(Boolean validationEnabled) {
    this(new SyncSet(), validationEnabled);
  }
  public SyncSetBuilder(SyncSetFluent<?> fluent) {
    this(fluent, false);
  }
  public SyncSetBuilder(SyncSetFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new SyncSet(), validationEnabled);
  }
  public SyncSetBuilder(SyncSetFluent<?> fluent,SyncSet instance) {
    this(fluent, instance, false);
  }
  public SyncSetBuilder(SyncSetFluent<?> fluent,SyncSet instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withApiVersion(instance.getApiVersion()); 
    fluent.withKind(instance.getKind()); 
    fluent.withMetadata(instance.getMetadata()); 
    fluent.withSpec(instance.getSpec()); 
    fluent.withStatus(instance.getStatus()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public SyncSetBuilder(SyncSet instance) {
    this(instance,false);
  }
  public SyncSetBuilder(SyncSet instance,Boolean validationEnabled) {
    this.fluent = this; 
    this.withApiVersion(instance.getApiVersion()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.withSpec(instance.getSpec()); 
    this.withStatus(instance.getStatus()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  SyncSetFluent<?> fluent;
  Boolean validationEnabled;
  public SyncSet build() {
    SyncSet buildable = new SyncSet(fluent.getApiVersion(),fluent.getKind(),fluent.getMetadata(),fluent.getSpec(),fluent.getStatus());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
